@@ -38,7 +38,7 @@
 #include "comp_range/port.h"
 
 
-char tmp_block[MAX_DACT_BLK_SIZE];
+char *tmp_block;
 
 int count_i=0;
 
@@ -77,8 +77,13 @@ int comp_range_compress(unsigned char *prev_block, unsigned char *curr_block, ch
 	rangecoder rc;
 	int i,x;
 
+	if ((tmp_block=malloc(DACT_BLK_SIZE))==NULL) {
+		return(-1);
+	}
+
+
 	count_i=0;
-	for (x=0;x<sizeof(tmp_block);x++) tmp_block[x]=0;
+	for (x=0;x<DACT_BLK_SIZE;x++) tmp_block[x]=0;
 	byte_buffer_purge();
 	byte_buffer_write(curr_block, blk_size);
 
@@ -91,7 +96,7 @@ int comp_range_compress(unsigned char *prev_block, unsigned char *curr_block, ch
 
 	for (x=0;x<256;x++) {
 		encode_short(&rc,counts[x]);
-//		printf("={ 0x%02x, 0x%04x }\n",x,counts[x]);
+/*		printf("={ 0x%02x, 0x%04x }\n",x,counts[x]); */
 	}
 
 	counts[256]=blk_size;
@@ -99,7 +104,7 @@ int comp_range_compress(unsigned char *prev_block, unsigned char *curr_block, ch
 
 	for (i=0;i<blk_size;i++) {
 		ch=curr_block[i];
-//printf("i=%5i ch=0x%02x -- counts[ch+1]=0x%02x counts[ch]=0x%02x\n",i,ch,counts[ch+1],counts[ch]);
+/*		printf("i=%5i ch=0x%02x -- counts[ch+1]=0x%02x counts[ch]=0x%02x\n",i,ch,counts[ch+1],counts[ch]); */
 		encode_freq(&rc,counts[ch+1]-counts[ch],counts[ch],counts[256]);
 	}
 
@@ -113,6 +118,7 @@ int comp_range_compress(unsigned char *prev_block, unsigned char *curr_block, ch
 		out_block[i]=tmp_block[i];
 	}
 
+	free(tmp_block);
 	return(count_i);
 }
 
@@ -122,10 +128,12 @@ int comp_range_decompress(unsigned char *prev_block, unsigned char *curr_block,
 	freq counts[257], tmp, cf, symbol;
 	rangecoder rc;
 
+	tmp_block=malloc(DACT_BLK_SIZE);
+
 	byte_buffer_purge();
 	byte_buffer_write(curr_block, blk_size);
 	count_i=0;
-	for (x=0;x<sizeof(tmp_block);x++) tmp_block[x]=0;
+	for (x=0;x<DACT_BLK_SIZE;x++) tmp_block[x]=0;
 
 	start_decoding(&rc);
 	cf = decode_culfreq(&rc,2);
@@ -151,14 +159,14 @@ int comp_range_decompress(unsigned char *prev_block, unsigned char *curr_block,
 
 	done_decoding(&rc);
 
-
+// Why am I not memcpy()'ing?
 	for (i=0;i<count_i;i++) out_block[i]=tmp_block[i];
 
-
+	free(tmp_block);
 	return(count_i);
 }
 
 void incoming_data(unsigned char value) {
-	if (count_i<=sizeof(tmp_block))
+	if (count_i<=(BYTE_BUFF_SIZE))
 		tmp_block[count_i++]=value;
 }
