@@ -452,6 +452,7 @@ int main(int argc, char **argv) {
 	unsigned char options[8]={0,0,0,0,0,0,0,0};
 	signed char opt;
 	char **in_files, *in_file=NULL, *out_file=NULL;
+	char dact_binfile[256];
 	int filecnt=0;
 	int in_fd, out_fd;
 	int mode=DACT_MODE_COMPR;
@@ -459,7 +460,28 @@ int main(int argc, char **argv) {
 
 
 	dact_loadconfig(DACT_CONFIG_FILE, options);
+#ifndef GO32
+	strncpy(dact_binfile,getenv("HOME"),sizeof(dact_binfile)-1);
+	strncat(dact_binfile,"/.dact/dact.conf",sizeof(dact_binfile)-strlen(dact_binfile)-1);
+	dact_loadconfig(dact_binfile, options);
+#endif
 
+	if (options[DACT_OPT_BINCHK]) {
+#ifdef GO32
+		strcpy(dact_binfile,"c:/dact/dact.exe");
+#else
+		strncpy(dact_binfile,getenv("HOME"),sizeof(dact_binfile)-1);
+		strncat(dact_binfile,"/.dact/dact.bin",sizeof(dact_binfile)-strlen(dact_binfile)-1);
+#endif
+
+		if (strcmp(argv[0],dact_binfile)) {
+			if (!access(dact_binfile,X_OK)) {
+				argv[0]=dact_binfile;
+				execv(dact_binfile,argv);
+			}
+		}
+	}
+ 
 	while ((opt=getopt(argc,argv,"dfsvcCm:e:lb:h"))!=-1) {
 		switch (opt) {
 			case 'd':
