@@ -5,7 +5,7 @@
 
 #define DACT_VER_MAJOR 0
 #define DACT_VER_MINOR 6
-#define DACT_VER_REVISION 3
+#define DACT_VER_REVISION 4
 
 #define DACT_MODE_COMPR 1
 #define DACT_MODE_DECMP 2
@@ -37,7 +37,7 @@
 #include "strsep.h"
 #endif
 
-#define DACT_MAGIC_NUMBER 0x44414354
+#define DACT_MAGIC_NUMBER 0x444354C3
 #define DACT_MAGIC_OFFSET 0
 #define DACT_MAGIC_SIZE   4
 #define DACT_MAGIC_PEOF   0xFF3FDE08
